@@ -20,6 +20,7 @@
 #include "volumemonitor.h"
 
 #include "globalactioncollection.h"
+#include "globalconfig.h"
 #include "listitemmenu.h"
 #include "microphoneindicator.h"
 #include "speakertest.h"
@@ -60,6 +61,7 @@ void Plugin::registerTypes(const char *uri)
     qmlRegisterType<VolumeOSD>(uri, 0, 1, "VolumeOSD");
     qmlRegisterType<VolumeFeedback>(uri, 0, 1, "VolumeFeedback");
     qmlRegisterType<SpeakerTest>(uri, 0, 1, "SpeakerTest");
+    qmlRegisterType<GlobalConfig>(uri, 0, 1, "GlobalConfig");
     qmlRegisterSingletonType(uri, 0, 1, "PulseAudio", pulseaudio_singleton);
     qmlRegisterSingletonType<MicrophoneIndicator>(uri, 0, 1, "MicrophoneIndicator", [](QQmlEngine *engine, QJSEngine *jsEngine) -> QObject * {
         Q_UNUSED(engine);
